@@ -4,16 +4,18 @@ import (
 	"fmt"
 	"strings"
 
+	progress_ "github.com/charmbracelet/bubbles/progress"
 	"github.com/charmbracelet/bubbles/spinner"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
 	"github.com/jandedobbeleer/oh-my-posh/src/build"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
+	"github.com/jandedobbeleer/oh-my-posh/src/progress"
 )
 
 var (
 	program   *tea.Program
-	textStyle = lipgloss.NewStyle().Margin(1, 0, 2, 0)
-	title     string
+	textStyle = lipgloss.NewStyle().Margin(1, 0, 2, 2)
 )
 
 type resultMsg string
@@ -38,18 +40,22 @@ func setState(message state) {
 type stateMsg state
 
 type model struct {
-	error   error
-	config  *Config
-	message string
-	spinner spinner.Model
-	state   state
+	error    error
+	config   *Config
+	spinner  *spinner.Model
+	progress *progress.Model
+	message  string
+	state    state
 }
 
 func initialModel(cfg *Config) *model {
 	s := spinner.New()
 	s.Spinner = spinner.Dot
 	s.Style = lipgloss.NewStyle().Foreground(lipgloss.Color("170"))
-	return &model{spinner: s, config: cfg}
+
+	p := progress.NewModel()
+
+	return &model{spinner: &s, config: cfg, progress: p}
 }
 
 func (m *model) Init() tea.Cmd {
@@ -61,7 +67,8 @@ func (m *model) Init() tea.Cmd {
 func (m *model) start() {
 	if err := install(m.config); err != nil {
 		m.error = err
-		program.Send(resultMsg(fmt.Sprintf("❌ upgrade failed: %v", err)))
+		log.Debug("failed to install")
+		program.Send(resultMsg(fmt.Sprintf(" ❌ upgrade failed: %v", err)))
 		return
 	}
 
@@ -69,6 +76,7 @@ func (m *model) start() {
 
 	current := fmt.Sprintf("v%s", build.Version)
 	if current != m.config.Version {
+		log.Debug("new version installed, user needs to restart shell")
 		message += ", restart your shell to take full advantage of the new functionality"
 	}
 
@@ -93,16 +101,22 @@ func (m *model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		m.state = state(msg)
 		return m, nil
 
+	case progress.Message:
+		return m, m.progress.SetPercent(float64(msg))
+
+	case progress_.FrameMsg:
+		return m, m.progress.Update(msg)
+
 	default:
-		var cmd tea.Cmd
-		m.spinner, cmd = m.spinner.Update(msg)
+		s, cmd := m.spinner.Update(msg)
+		m.spinner = &s
 		return m, cmd
 	}
 }
 
 func (m *model) View() string {
 	if len(m.message) > 0 {
-		return title + textStyle.Render(m.message)
+		return textStyle.Render(m.message)
 	}
 
 	var message string
@@ -112,8 +126,8 @@ func (m *model) View() string {
 	case validating:
 		message = "Validating current installation"
 	case downloading:
-		m.spinner.Spinner = spinner.Globe
-		message = fmt.Sprintf("Downloading latest version from %s", m.config.Source.String())
+		message = fmt.Sprintf("Downloading %s from %s...\n%s", m.config.Version, m.config.Source.String(), m.progress.View())
+		return textStyle.Render(message)
 	case verifying:
 		m.spinner.Spinner = spinner.Moon
 		message = "Verifying download"
@@ -122,26 +136,16 @@ func (m *model) View() string {
 		message = "Installing"
 	}
 
-	return title + textStyle.Render(fmt.Sprintf("%s %s", m.spinner.View(), message))
+	return textStyle.Render(fmt.Sprintf("%s %s", m.spinner.View(), message))
 }
 
 func Run(cfg *Config) error {
-	titleStyle := lipgloss.NewStyle().Margin(1, 0, 1, 0)
-	title = "📦 Upgrading Oh My Posh"
-
-	current := fmt.Sprintf("v%s", build.Version)
-	if len(current) == 0 {
-		current = "dev"
-	}
-
-	title = fmt.Sprintf("%s from %s to %s", title, current, cfg.Version)
-	title = titleStyle.Render(title)
-
 	program = tea.NewProgram(initialModel(cfg))
 	resultModel, _ := program.Run()
 
 	programModel, OK := resultModel.(*model)
 	if !OK {
+		log.Debug("failed to cast model")
 		return nil
 	}
 
