@@ -5,7 +5,7 @@ module.exports = {
   tagline: 'A prompt theme engine for any shell.',
   url: 'https://ohmyposh.dev',
   baseUrl: '/',
-  favicon: 'img/favicon.ico',
+  favicon: 'img/favicons.svg',
   organizationName: 'jandedobbeleer',
   projectName: 'oh-my-posh',
   onBrokenLinks: 'ignore',
@@ -50,6 +50,11 @@ module.exports = {
           label: 'Sponsor',
           position: 'left',
         },
+        {
+          href: 'https://polar.sh/oh-my-posh',
+          label: 'Buy',
+          position: 'left',
+        },
         {
           href: 'https://swag.ohmyposh.dev',
           label: 'Swag',
@@ -62,9 +67,9 @@ module.exports = {
           position: 'right',
         },
         {
-          href: 'https://www.gitkraken.com/invite/nQmDPR9D',
-          className: 'header-gk-link',
-          'aria-label': 'GitKraken',
+          href: 'https://www.warp.dev/oh-my-posh',
+          className: 'header-affiliate-link',
+          'aria-label': 'Warp',
           position: 'right',
         },
         {
@@ -122,8 +127,12 @@ module.exports = {
               href: 'https://github.com/sponsors/JanDeDobbeleer',
             },
             {
-              label: 'GitKraken',
-              href: 'https://www.gitkraken.com/invite/nQmDPR9D',
+              label: 'Buy',
+              href: 'https://polar.sh/oh-my-posh',
+            },
+            {
+              label: 'Warp',
+              href: 'https://www.warp.dev/oh-my-posh',
             },
             {
               label: 'Docusaurus',
